import os
import json

def create_new_layout_with_instances(object_types_folder, new_layout_json_path, x=0, y=0):
    # Initialize the basic structure of the layout JSON
    new_layout_data = {
        "name": "New Layout",
        "layers": [{
            "name": "Layer 0",
            "instances": [],
            # Add other layer properties as needed
        }],
        # Add other layout properties as needed
    }

    # Assuming instances are to be added in the first layer
    layer = new_layout_data['layers'][0]

    # UID counter - start from a high number to avoid conflicts
    uid_counter = 100

    # Loop through the object types and add them to the new layout
    for object_file in os.listdir(object_types_folder):
        if object_file.endswith('.json'):
            object_type = os.path.splitext(object_file)[0]

            instance = {
                "type": object_type,
                "properties": {
                    "initially-visible": True,
                    "initial-animation": "Default",
                    "initial-frame": 0,
                    "enable-collisions": True,
                    "live-preview": False
                },
                "uid": uid_counter,
                "instanceVariables": {},
                "behaviors": {},
                "world": {
                    "x": x,
                    "y": y,
                    # Default values, adjust as needed
                    "width": 768,
                    "height": 1145,
                    "originX": 0.5,
                    "originY": 0.5,
                    "color": [1, 1, 1, 1],
                    "angle": 0,
                    "zElevation": 0
                }
            }

            # Add the instance to the new layout
            layer['instances'].append(instance)
            uid_counter += 1

    # Save the new layout JSON file
    with open(new_layout_json_path, 'w') as file:
        json.dump(new_layout_data, file, indent=4)

    print(f"New layout file created: {new_layout_json_path}")

# Paths to your object types folder and the new layout JSON file
object_types_folder = '.'
new_layout_json_path = './new_layout.json'

# Call the function
create_new_layout_with_instances(object_types_folder, new_layout_json_path)

